;**************************************************************************
;* FileName	: KEY4TEST.ASM
;* Date 	: 31.01.2001
;* File version : v1.00
;*
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.fw.hu
;* E-mail	: majki@fw.hu
;*
;*-------------------------------------------------------------------------
;*
;* Description	: KEY4 test
;*		  ==================================
;*		  Testcode for KEY4.
;*
;*
;*-------------------------------------------------------------------------
;*
;* Connections	:	       _______	 _______
;*			      |       \_/	|
;*		     -reset ==| -MCLR	    RB7 |== KEY_4
;*		  RS232_TxD ==| RA0	    RB6 |== KEY_3
;*		  RS232_RxD ==| RA1	    RB5 |== KEY_2
;*		        n.c ==| RA2	    RB4 |== KEY_1
;*  		        n.c ==| RA3	    RB3 |== n.c
;*		        n.c ==| RA4	    RB2 |== n.c
;*		        n.c ==| RA5	    RB1 |== n.c
;*		        GND ==| Vss	    RB0 |== n.c
;*		    quartz1 ==| OSC1	    Vdd |== +5V
;*		    quartz2 ==| OSC2	    Vss |== GND
;*	                n.c ==| RC0	    RC7 |== n.c
;*		        n.c ==| RC1	    RC6 |== n.c
;*		        n.c ==| RC2	    RC5 |== n.c
;*		        n.c ==| RC3	    RC4 |== n.c
;*			      |_________________|
;*				   PIC16F872 
;*
;*-------------------------------------------------------------------------
;*
;* Resource	: Ports 	  :    xx /   22 pin   (   %)
;*		  Data memory	  :    xx /  128 byte  (   %)
;*		  Prog memory	  :   xxx / 2048 word  (   %)
;*		  EEPROM	  :    xx /   64 byte  (   %)
;*		  Timers	  : 
;*		  Interrupt	  : 
;*		  CCP		  :
;*		  MSSP		  :
;*		  AD		  :
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  31/01/2001 	Initial Release
;*
;**************************************************************************

	list	p=16f872, r=dec, l=0

;***** INCLUDES ***********************************************************

	include "p16f872.inc"
	include	"..\..\modules\base.inc"

;***** CONFIG ************************************************************

CFG_1	EQU 	_XT_OSC & _WDT_OFF & _PWRTE_ON & _BODEN_ON & _LVP_OFF
CFG_2	EQU	_CPD_OFF & _WRT_ENABLE_OFF & _DEBUG_OFF & _CP_OFF

	__CONFIG CFG_1 & CFG_2
	__IDLOCS 0100h			; version

	EXPAND_MACROS	EXP_COND	; macro expansion mode

;***** DEFINES ************************************************************

;#define DEBUG				; for some debug message
;#define NO_DELAY			; for fast simulation
;#define NO_RS232			; for fast simulation

xtal_freq	EQU	3579545	  	; crystal frequency
core_freq	EQU	xtal_freq/4	; core operating frequency

TIMER_TMR0pre	EQU	256	  	; timer0 prescaler value (2, 4, .. 256)
TIMER_TMR0val	EQU	128		; TMR0 init value (1-256)


; ----- porta -------------------------------------------------------------

#define		RS232_TxD	PORTA,0		; out
#define		RS232_RxD	PORTA,1		; in
#define		PORTA_2		PORTA,2		; free
#define		PORTA_3		PORTA,3		; free
#define		PORTA_4		PORTA,4		; free (open drain!)
#define		PORTA_5		PORTA,5		; free

; ----- portb -------------------------------------------------------------

#define		PORTB_0		PORTB,0		; free
#define		PORTB_1		PORTB,1		; free
#define		PORTB_2		PORTB,2		; free
#define		PORTB_3		PORTB,3		; free
#define		KEY4_1		PORTB,4		; in
#define		KEY4_2		PORTB,5		; in
#define		KEY4_3		PORTB,6		; in
#define		KEY4_4		PORTB,7		; in

; ----- portc -------------------------------------------------------------

#define		PORTC_0		PORTC,0		; free
#define		PORTC_1		PORTC,1		; free
#define		PORTC_2		PORTC,2		; free
#define		PORTC_3		PORTC,3		; free
#define		PORTC_4		PORTC,4		; free
#define		PORTC_5		PORTC,5		; free
#define		PORTC_6		PORTC,6		; free
#define		PORTC_7		PORTC,7		; free





;***** MACROS *************************************************************

	include "..\..\modules\wait.mac"
	include	"..\..\modules\rs232.mac"
	include "..\..\modules\key4.mac"

; -------------------------------------------------------------------------


;***** CONSTANT DEFINITIONS ***********************************************

option_val	EQU	00000010b	; Timer source : intclk / 8
trisa_val	EQU	00111111b	; TRISA value (all input)
trisb_val	EQU	11111111b	; TRISB value (all input)
trisc_val	EQU	11111111b	; TRISC value (all input)
adcon0_val	EQU	00000000b	; ADCON0 value (AD off)
adcon1_val	EQU	00000110b	; ADCON1 value (all digital input)
intcon_val	EQU	00100000b	; Interrupt control


 




;***** VARIABLE DEFINITIONS ***********************************************
	cblock	70h			; common RAM
		w_temp			; variable used for context saving
		status_temp		; variable used for context saving
		fsr_temp		; variable used for context saving
	endc

;--------------------------------------------------------------------------
	cblock	20h

	;	TEMP			; dummy register



	endc




;***** ENTRY POINT ********************************************************
		ORG	000h		; processor reset vector
		nop
		clrwdt
		clrf	STATUS
		goto	start


;***** IT HANDLER *********************************************************
;* Interrupt handler
;* <comment>
;**************************************************************************
		ORG	004h		; interrupt vector location
IT_service	movwf	w_temp		; save off current W register contents
		swapf	STATUS,w	; move STATUS register into W register
		movwf	status_temp	; save off contents of STATUS register

		movf	FSR,w		; save FSR
		movwf	fsr_temp
;--------------------------------------------------------------------------

	;	<IT code>


;--------------------------------------------------------------------------
IT_restore	movf	fsr_temp,w	; restore FSR
		movwf	FSR

		swapf	status_temp,w	; retrieve copy of STATUS register
		movwf	STATUS		; restore pre-isr STATUS register contents
		swapf	w_temp,f
		swapf	w_temp,w	; restore pre-isr W register contents
		retfie			; return from interrupt


;--------------------------------------------------------------------------

;***** REAL PROGRAM START *************************************************
start
;----- set configuration --------------------------------------------------
		clrf	PORTA		; clear latch
		clrf	PORTB		; clear latch
		clrf	PORTC		; clear latch
		bank1
		ERRORLEVEL -302
		movlw	option_val
		movwf	OPTION_REG	; set OPTION_REG
		movlw	trisa_val
		movwf	TRISA		; set TRISA
		movlw	trisb_val
		movwf	TRISB		; set TRISB
		movlw	trisc_val
		movwf	TRISC		; set TRISC
		movlw	adcon1_val	
		movwf	ADCON1		; set ADCON1
		bank0
		ERRORLEVEL +302
		movlw	adcon0_val	
		movwf	ADCON0		; set ADCON0
		movlw	intcon_val	
		movwf	INTCON		; set INTCON

;----- inits --------------------------------------------------------------

		RS232_INIT	9600, 8, 1
		KEY4_INIT


;----- main cycle  --------------------------------------------------------

		RS232_SENDCS "PIC: "


main_cycle	nop
		
		KEY4_POLL
		
		WAIT	10 Millisec, 0

		KEY4_GET

		testw
		skipz
		
		RS232_SENDW
		



		goto	main_cycle		












;***** SUB1 ***************************************************************
;* 
;* Input :              		; 
;* Output:  				; 
;* Clock :   
;**************************************************************************

sub1 


		return

;***** INCLUDES ***********************************************************

	include "..\..\modules\wait.inc"
	include "..\..\modules\rs232.inc"
	include "..\..\modules\key4.inc"

;**************************************************************************
	end				  ; end of program








